import 'package:templatr/html.dart';
import 'package:templatr/widget.dart';

String form({
  String id,
  Map<String, String> style,
  Map<String, String> data = const {},
  List<String> classes,
  List<String> content = const [],
  bool validate = true,
}) =>
    ElementWidget(
      'sl-form',
      id: id,
      style: style,
      classes: classes,
      attributes: {
        'novalidate': !validate,
        ...data.map((key, value) => MapEntry('data-$key', value)),
      },
      newlineAfterStart: true,
    )(content);

String input({
  String id,
  Map<String, String> style, 
  Map<String, String> data = const {},
  List<String> classes,
  String name,
  InputType type,
  String label,
  String value,
  bool disabled,
  bool readonly,
  bool required,
  String pattern,
  String help,
}) =>
    ElementWidget(
      'sl-input',
      id: id,
      style: style,
      classes: classes,
      attributes: {
        'name': name,
        'type': type?.name,
        'label': label,
        'value': value,
        'disabled': disabled,
        'readonly': readonly,
        'required': required,
        'pattern': pattern,
        ...data.map((key, value) => MapEntry('data-$key', value)),
      },
    )(help != null ? small(help, slot: 'help-text') : null);

String select({
  String id,
  Map<String, String> style,
  List<String> classes,
  String name,
  String label,
  List<String> items = const [],
  bool disabled,
  bool readonly,
  bool required,
}) =>
    ElementWidget(
      'sl-select',
      id: id,
      style: style,
      classes: classes,
      attributes: {
        'name': name,
        'label': label,
        'disabled': disabled,
        'readonly': readonly,
        'required': required,
      },
      newlineAfterStart: true,
    )(items);

String checkbox(String label, {
  String id,
  Map<String, String> style,
  List<String> classes,
  String name,
  bool checked = false,
  String value,
}) =>
    ElementWidget(
      'sl-checkbox',
      id: id,
      style: style,
      classes: classes,
      attributes: {
        'name': name,
        'checked': checked,
        'value': value,
      },
    )(label);
